<?php

namespace Litecms\Profile\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Profile\Models\Profile;

class ProfilePolicy
{

    /**
     * Determine if the given user can view the profile.
     *
     * @param UserPolicy $user
     * @param Profile $profile
     *
     * @return bool
     */
    public function view(UserPolicy $user, Profile $profile)
    {
        if ($user->canDo('profile.profile.view') && $user->isAdmin()) {
            return true;
        }

        return $profile->user_id == user_id() && $profile->user_type == user_type();
    }

    /**
     * Determine if the given user can create a profile.
     *
     * @param UserPolicy $user
     * @param Profile $profile
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('profile.profile.create');
    }

    /**
     * Determine if the given user can update the given profile.
     *
     * @param UserPolicy $user
     * @param Profile $profile
     *
     * @return bool
     */
    public function update(UserPolicy $user, Profile $profile)
    {
        if ($user->canDo('profile.profile.edit') && $user->isAdmin()) {
            return true;
        }

        return $profile->user_id == user_id() && $profile->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given profile.
     *
     * @param UserPolicy $user
     * @param Profile $profile
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Profile $profile)
    {
        return $profile->user_id == user_id() && $profile->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given profile.
     *
     * @param UserPolicy $user
     * @param Profile $profile
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Profile $profile)
    {
        if ($user->canDo('profile.profile.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given profile.
     *
     * @param UserPolicy $user
     * @param Profile $profile
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Profile $profile)
    {
        if ($user->canDo('profile.profile.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
